@@ -1,7 +1,7 @@
 """
 Type annotations for wisdom service literal definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_wisdom/literals.html)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_wisdom/literals/)
 
 Usage::
 
@@ -40,6 +40,7 @@ __all__ = (
     "ServiceName",
     "ResourceServiceName",
     "PaginatorName",
+    "RegionName",
 )
 
 
@@ -200,6 +201,7 @@ ServiceName = Literal[
     "frauddetector",
     "fsx",
     "gamelift",
+    "gamesparks",
     "glacier",
     "globalaccelerator",
     "glue",
@@ -406,3 +408,6 @@ PaginatorName = Literal[
     "search_content",
     "search_sessions",
 ]
+RegionName = Literal[
+    "ap-northeast-1", "ap-southeast-2", "eu-central-1", "eu-west-2", "us-east-1", "us-west-2"
+]
