@@ -1,7 +1,7 @@
 """
 Type annotations for wisdom service type definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_wisdom/type_defs.html)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_wisdom/type_defs/)
 
 Usage::
 
@@ -81,12 +81,16 @@ __all__ = (
     "KnowledgeBaseAssociationDataTypeDef",
     "KnowledgeBaseDataTypeDef",
     "KnowledgeBaseSummaryTypeDef",
+    "ListAssistantAssociationsRequestListAssistantAssociationsPaginateTypeDef",
     "ListAssistantAssociationsRequestRequestTypeDef",
     "ListAssistantAssociationsResponseTypeDef",
+    "ListAssistantsRequestListAssistantsPaginateTypeDef",
     "ListAssistantsRequestRequestTypeDef",
     "ListAssistantsResponseTypeDef",
+    "ListContentsRequestListContentsPaginateTypeDef",
     "ListContentsRequestRequestTypeDef",
     "ListContentsResponseTypeDef",
+    "ListKnowledgeBasesRequestListKnowledgeBasesPaginateTypeDef",
     "ListKnowledgeBasesRequestRequestTypeDef",
     "ListKnowledgeBasesResponseTypeDef",
     "ListTagsForResourceRequestRequestTypeDef",
@@ -95,6 +99,7 @@ __all__ = (
     "NotifyRecommendationsReceivedRequestRequestTypeDef",
     "NotifyRecommendationsReceivedResponseTypeDef",
     "PaginatorConfigTypeDef",
+    "QueryAssistantRequestQueryAssistantPaginateTypeDef",
     "QueryAssistantRequestRequestTypeDef",
     "QueryAssistantResponseTypeDef",
     "RecommendationDataTypeDef",
@@ -103,9 +108,11 @@ __all__ = (
     "ResponseMetadataTypeDef",
     "ResultDataTypeDef",
     "SearchContentRequestRequestTypeDef",
+    "SearchContentRequestSearchContentPaginateTypeDef",
     "SearchContentResponseTypeDef",
     "SearchExpressionTypeDef",
     "SearchSessionsRequestRequestTypeDef",
+    "SearchSessionsRequestSearchSessionsPaginateTypeDef",
     "SearchSessionsResponseTypeDef",
     "ServerSideEncryptionConfigurationTypeDef",
     "SessionDataTypeDef",
@@ -575,6 +582,14 @@ KnowledgeBaseSummaryTypeDef = TypedDict(
     },
 )
 
+ListAssistantAssociationsRequestListAssistantAssociationsPaginateTypeDef = TypedDict(
+    "ListAssistantAssociationsRequestListAssistantAssociationsPaginateTypeDef",
+    {
+        "assistantId": str,
+        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
+    },
+)
+
 ListAssistantAssociationsRequestRequestTypeDef = TypedDict(
     "ListAssistantAssociationsRequestRequestTypeDef",
     {
@@ -593,6 +608,13 @@ ListAssistantAssociationsResponseTypeDef = TypedDict(
     },
 )
 
+ListAssistantsRequestListAssistantsPaginateTypeDef = TypedDict(
+    "ListAssistantsRequestListAssistantsPaginateTypeDef",
+    {
+        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
+    },
+)
+
 ListAssistantsRequestRequestTypeDef = TypedDict(
     "ListAssistantsRequestRequestTypeDef",
     {
@@ -610,6 +632,14 @@ ListAssistantsResponseTypeDef = TypedDict(
     },
 )
 
+ListContentsRequestListContentsPaginateTypeDef = TypedDict(
+    "ListContentsRequestListContentsPaginateTypeDef",
+    {
+        "knowledgeBaseId": str,
+        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
+    },
+)
+
 ListContentsRequestRequestTypeDef = TypedDict(
     "ListContentsRequestRequestTypeDef",
     {
@@ -628,6 +658,13 @@ ListContentsResponseTypeDef = TypedDict(
     },
 )
 
+ListKnowledgeBasesRequestListKnowledgeBasesPaginateTypeDef = TypedDict(
+    "ListKnowledgeBasesRequestListKnowledgeBasesPaginateTypeDef",
+    {
+        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
+    },
+)
+
 ListKnowledgeBasesRequestRequestTypeDef = TypedDict(
     "ListKnowledgeBasesRequestRequestTypeDef",
     {
@@ -695,6 +732,15 @@ PaginatorConfigTypeDef = TypedDict(
     },
 )
 
+QueryAssistantRequestQueryAssistantPaginateTypeDef = TypedDict(
+    "QueryAssistantRequestQueryAssistantPaginateTypeDef",
+    {
+        "assistantId": str,
+        "queryText": str,
+        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
+    },
+)
+
 QueryAssistantRequestRequestTypeDef = TypedDict(
     "QueryAssistantRequestRequestTypeDef",
     {
@@ -768,6 +814,15 @@ SearchContentRequestRequestTypeDef = TypedDict(
     },
 )
 
+SearchContentRequestSearchContentPaginateTypeDef = TypedDict(
+    "SearchContentRequestSearchContentPaginateTypeDef",
+    {
+        "knowledgeBaseId": str,
+        "searchExpression": "SearchExpressionTypeDef",
+        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
+    },
+)
+
 SearchContentResponseTypeDef = TypedDict(
     "SearchContentResponseTypeDef",
     {
@@ -794,6 +849,15 @@ SearchSessionsRequestRequestTypeDef = TypedDict(
     },
 )
 
+SearchSessionsRequestSearchSessionsPaginateTypeDef = TypedDict(
+    "SearchSessionsRequestSearchSessionsPaginateTypeDef",
+    {
+        "assistantId": str,
+        "searchExpression": "SearchExpressionTypeDef",
+        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
+    },
+)
+
 SearchSessionsResponseTypeDef = TypedDict(
     "SearchSessionsResponseTypeDef",
     {
